# Ansible Extra Tools

Extra tools for Ansible

## Installation

`python3 -m pip install ansible-extra-tools`

## Ansible Role

The `ansible-role` package is used for running role(s) on targeted hosts.

Functions similar to `ansible-playbook` and other Ansible CLI tools.

`ansible-role [OPTIONS] --limit SUBSET ROLE_NAME`

## License

GNU General Public License v3.0 or later
